FastStyleAssetsLoaderConfig class final

Model loader configuration using asset paths.

Use this when your models are bundled inside the app's asset folder.

Inheritance

Constructors

FastStyleAssetsLoaderConfig({required String predictResource, required String styleTransferResource})
Constructs an asset-based loader config.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
predictResource String
Resource for the style prediction model.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleTransferResource String
Resource for the style transfer model.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited