FastStyleFileLoaderConfig class final
Model loader configuration using file system.
Use this when your models are stored in local files (e.g., downloaded).
- Inheritance
-
- Object
- FastStyleLoaderConfig<
File> - FastStyleFileLoaderConfig
Constructors
- FastStyleFileLoaderConfig({required File predictResource, required File styleTransferResource})
-
Constructs a file-based loader config.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- predictResource → File
-
Resource for the style prediction model.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- styleTransferResource → File
-
Resource for the style transfer model.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited